@@ -65,7 +65,7 @@ goldsectmin <- function(f, a, b, tol = 1e-3, m = 100) {
     while (abs(b - a) > tol) {
         iter <- iter + 1
         if (iter > m) {
-            warning("maximum number of iterations exceeded")
+            warning("iterations maximum exceeded")
             break
         }
 
@@ -95,7 +95,7 @@ goldsectmax <- function(f, a, b, tol = 1e-3, m = 100) {
     while (abs(b - a) > tol) {
         iter <- iter + 1
         if (iter > m) {
-            warning("maximum number of iterations exceeded")
+            warning("iterations maximum exceeded")
             break
         }
 
